**Example 1: 示例**



Input: 

```
tccli redis ModifyMaintenanceWindow --cli-unfold-argument  \
    --InstanceId crs-5a4py64p \
    --StartTime 03:00 \
    --EndTime 06:00
```

Output: 
```
{
    "Response": {
        "Status": "success",
        "RequestId": "0e728fa9-c2e5-4bf8-8d6b-c1c4fab7b6db"
    }
}
```

